@@ -363,9 +363,9 @@ def epoc_filter(data, epoc, *, values=None, modifiers=None, t=None, tref=False,
             else:
                 data.snips[k].ts = data.snips[k].ts[keep]
             
-            # if there are any extra fields, keep those
+            # if there are any extra array fields, like sortcode, trim that array too
             for kk in data.snips[k].keys():
-                if kk in ['ts', 'name', 'data', 'sortname', 'fs', 'code', 'size', 'type', 'dform']:
+                if kk in ['ts', 'data'] or not isinstance(data.snips[k][kk], np.ndarray):
                     continue
                 if len(data.snips[k][kk]) >= np.max(keep):
                     data.snips[k][kk] = data.snips[k][kk][keep]
